#
# spec file for package glyr
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major   1

Name:           glyr
Version:        1.0.10
Release:        4.2
Summary:        Search engine for music related metadata
License:        LGPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/sahib/glyr
Source0:        https://github.com/sahib/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source100:      baselibs.conf
# PATCH-FIX-OPENSUSE glyr-date-n-time.patch lazy.kent@opensuse.org -- remove __DATE__ and __TIME__ that causes the package to rebuild when not needed
Patch0:         glyr-date-n-time.patch
# PATCH-FIX-OPENSUSE glyr-optflags.patch lazy.kent@opensuse.org -- use default openSUSE optimization flags.
Patch1:         glyr-optflags.patch
# PATCH-FIX-OPENSUSE glyr-pkgconfig.patch crrodriguez@opensuse.org -- do not inject bogus dependencies into other packages.
Patch2:         glyr-pkgconfig.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(sqlite3)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The sort of metadata glyr is searching (and downloading) is usually the
data you see in your music player. It was originally written
to serve as internal library for a music player, but has been extended
to work as a standalone program.

%package -n glyrc
Summary:        Search engine for music related metadata
Group:          Productivity/Networking/Web/Utilities
Provides:       glyr = %{version}
Obsoletes:      glyr < 1.0.0

%description -n glyrc
This subpackage contains the Glyr CLI tool.

The sort of metadata glyr is searching (and downloading) is usually the
data you see in your music player. It was originally written
to serve as internal library for a music player, but has been extended
to work as a standalone program which is able to download:

* cover art;
* lyrics;
* bandphotos;
* artist biography;
* album reviews;
* tracklists of an album;
* a list of albums from a specific artist;
* tags, either related to artist, album or title relations, for example
  links to Wikipedia;
* similar artists;
* similar songs.

%package -n lib%{name}%{major}
Summary:        Search engine for music related metadata
Group:          System/Libraries

%description -n lib%{name}%{major}
The Glyr shared library.

%package devel
Summary:        Development files for glyr, a music metadata search engine
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{major} = %{version}
Provides:       libglyr-devel = %{version}
Obsoletes:      libglyr-devel < 1.0.5

%description devel
Glyr development files.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 1 -p1
%patch -P 2

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n libglyr%{major} -p /sbin/ldconfig

%postun -n libglyr%{major} -p /sbin/ldconfig

%files -n glyrc
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS README.textile state_of_providers.txt
%{_bindir}/glyrc

%files -n lib%{name}%{major}
%defattr(-,root,root,-)
%license COPYING
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%license COPYING
%doc AUTHORS README.textile state_of_providers.txt
%doc src/examples
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Apr 30 2021 andreas@andreasvoegele.com
- Use %%cmake_build and %%license macros.
- Set License to LGPL-3.0-or-later.
* Thu Jan 26 2017 jengelh@inai.de
- Trim descriptions and fix spelling errors.
* Tue Nov 22 2016 lazy.kent@opensuse.org
- Update to 1.0.10.
  * Changed License to LGPLv3 (from GPLv3).
  * Fix lyricswiki provider.
  * Fix typos.
* Fri May 20 2016 lazy.kent@opensuse.org
- Update to 1.0.9.
  * Bugfixes:
    + Support reproducible builds.
    + Build problems.
    + Spelling errors.
  * Fixed providers:
    + lyrics/lyricswikia.
    + cover/slothradio.
    + cover/discogs.
- Drop glyr-version.patch: fixed upstream.
- Don't package CHANGELOG. It is obsolete and discontinued.
* Sat Feb 14 2015 lazy.kent@opensuse.org
- Update to 1.0.8.
  * Fix of lyrix.at.
- Update glyr-version.patch.
- Use %%cmake and %%cmake_install macros.
* Thu Jan  8 2015 lazy.kent@opensuse.org
- Update to 1.0.7.
  * lyricswiki fixed.
- Changes in 1.0.6.
  * Fixed faulty sha-1 versioning in cmakelists.
  * Make glyrc return EXIT_SUCESS on success or EXIT_FAILURE in
    case of any failure.
  * Made the -c (--cache) option have an optional argument. Without
    argument the path is ~/.cache/glyrc (will be created if
    necessary).
  * Clamp the timeout of select to the user-set timeout.
  * Fix for cache getter: Print like normal getters and also call
    appropiate programs.
- Refresh glyr-date-n-time.patch.
- Update glyr-version.patch.
* Thu Feb 13 2014 lazy.kent@opensuse.org
- Update to 1.0.5.
  * Quickfix: lyricswiki broken once more; fixed again.
  * Bugfix: cover|photo:discogs: fix crash when transformed url has
    only one dash.
  * Fix for instrumental songs on lyricswiki.
  * Fixed typos (searchenigne -> search engine, musicrelated ->
    music related).
  * lyrix_at: fix end of lyric.
- Rename libglyr-devel to glyr-devel.
- Drop glyr-image_discogs.patch (fixed upstream).
- Add glyr-version.patch: pushed version to 1.0.5 in CMakeLists.txt
  (fixed in git).
* Sun Dec 29 2013 lazy.kent@opensuse.org
- Add glyr-image_discogs.patch: cover|photo:discogs: fix crash when
  transformed url has only one dash (gh#sahib/glyr#41) (fixed in
  git).
* Thu Dec 26 2013 crrodriguez@opensuse.org
- CmakeLists.txt, -std=gnu99 is meant instead of -std=c99
  (extends  glyr-optflags.patch)
* Sat Dec  7 2013 lazy.kent@opensuse.org
- Drop glyr-fix_lyricswiki.patch (fixed upstream -- very quickly;
  no version change).
* Sat Dec  7 2013 lazy.kent@opensuse.org
- Add glyr-fix_lyricswiki.patch: fix lyrics parsing
  (gh#sahib/glyr#40).
* Sat Dec  7 2013 lazy.kent@opensuse.org
- Update to 1.0.2.
  * Fixed albumlist; Fixed partly broken lastfm.
  * Fixed tracklist.
  * Base implementation for the Vagalume lyrics provider.
  * lyrics-vagalume: Fixed tabs, small memleak, added memset.
  * Fixed cover:musicbrainz provider.
  * Fix empty lyrics from magistrix.
  * Updated htbackdrops uri.
  * Removed lyrics:metrolyrics provider (broken for eternity).
  * lyrics-vagalume: Ignore approximate results.
  * Fixed lyricswiki provider.
- BuildRequires: pkgconfig(glib-2.0) >= 2.32.
- Update "glyr-date-n-time" and "glyr-optflags" patches.
- Correct source URL.
- Add more docs to the devel package.
* Sun Mar  3 2013 schwab@suse.de
- Properly determine LIB_SUFFIX
* Fri Dec  7 2012 lazy.kent@opensuse.org
- Really add baselibs.conf (forgot to do in my previous commit).
* Thu Nov 22 2012 crrodriguez@opensuse.org
- glyr-pkgconfig.patch Do not inject bogus extra
  dependencies into the rest of system.
* Wed Oct  3 2012 lazy.kent@opensuse.org
- Update to 1.0.0.
  * Correct filename encoding for musictree.
  * Accept front.jpg.
  * Updated lyricsvip provider.
  * Removed allmusic.
  * Fixed lyrics:magistrix.
  * Added ainfo:bbcmusic and photos:bbcmusic.
  * Added coverartarchive provider.
  * Disabled albumart and guitaretab.com.
  * Added state_of_providers.txt.
  * --normalize option for glyrc.
  * Fixed little memory leak.
  * Removed TODO.
- Split off glyrc subpackage (CLI tool).
- Refresh date-n-time.patch.
- Add baselibs.conf.
* Fri Jul  6 2012 dvaleev@suse.com
- fix libdir for ppc64
* Mon May  7 2012 lazy.kent@opensuse.org
- Update to 0.9.9.
  * Added --as-one (and --no-as-one) option to glyrc.
  * Fixed up readme.
  * Updated help.
  * Added support for :escape: characters in --write and
  - -callback.
  * Added slothradio provider.
  * Various fixes.
- Rebase "date-n-time" and "optflags" patches.
* Fri Apr 13 2012 lazy.kent@opensuse.org
- Update to 0.9.8.
  * Fixed --musictree -> --musictree-path.
  * Updated help accordingly.
  * Fixed crash in relations:musicbrainz.
  * Fixed storing of getters with optional artist/album.
  * Added musicbrainz as cover provider.
  * Fix for -v0.
  * Added extra trimming for all text items.
  * Fixed magistrix parser.
  * Fixed incorrect trimming.
  * Fixed cover:albumart.
  * Made jamendo provider work inplace.
* Wed Mar  7 2012 lazy.kent@opensuse.org
- Update to 0.9.5.
  * Added Jamendo provider.
- Added examples to devel package.
- Removed _service - use tarball.
* Wed Feb 22 2012 lazy.kent@opensuse.org
- Update from git.
  * Updated discogs provider to new use the new API.
  * Updated README.
  * Fixed typos.
  * Fixed the unicode lookup problem.
- Updated "optflags" patch.
* Fri Feb 10 2012 lazy.kent@opensuse.org
- Update from git (various fixes).
- Updated "date-n-time" patch.
* Wed Feb  8 2012 lazy.kent@opensuse.org
- Added COPYING to libglyr* packages.
* Sat Feb  4 2012 lazy.kent@opensuse.org
- Update to 0.9.4.
- Patch to use default openSUSE optimisation flags.
* Sun Dec 25 2011 lazy.kent@opensuse.org
- Patch to remove __DATE and __TIME__ that causes the package to
  rebuild when not needed.
* Wed Dec 14 2011 lazy.kent@opensuse.org
- Initial package created - 0.9.
